Sign in

## Existing customerSign in / Register

Email address
Password
Sign in with your customer number Forgotten your password?
By signing in, you agree to the Book People’s Terms & Conditions and Privacy Policy.

Please correct the following errors:

Sign in with your customer number Forgotten your password?

or

Register By registering or signing in, you agree to the Book People’s Terms & Conditions and Privacy Policy.

## New customer

Don’t already have an account with the Book People?

Register today to place your order and enjoy our special offers.

Register

## UK schools and educational organisationsUK schools

Looking for an easier way to manage your school budget when it comes to buying books?

- With savings up to 75% off publishers' prices
- 30-day credit facility subject to approval. More info
- An easy, rewarding way to fill your classroom with brilliant books

Register for a School Account Register for a school account
I would like to change my existing UK account to a Schools Account.

To convert your UK account to a School Account, simply complete the form below:

### Existing account details

Email address
Password

### School details

Education type
Your position
Number of pupils
Did the local bookseller who visits your school recommend us to you?

### School address

Enter a BFPO address?
Country
Postcode
Results
School name
Address line 1
Address line 2
Town/city
County

Please correct the following errors:

By changing your account you agree to the Book People’s Terms & Conditions for School Credit Accounts